@@ -1,10 +1,17 @@
 import asyncio
 
 import aiohttp
-from notecoin.huobi.connection import RestApiSyncClient, WebSocketReqClient, SubscribeClient
-from notecoin.huobi.model.account import *
-from notecoin.huobi.utils import *
-from notecoin.huobi.utils.input_checker import check_in_list
+from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
+                                       WebSocketReqClient)
+from notecoin.huobi.constant import (AccountBalanceMode, AccountType,
+                                     HttpMethod, TransferFuturesPro,
+                                     TransferMasterType,
+                                     get_default_server_url)
+from notecoin.huobi.model.account import AccountBalance
+from notecoin.huobi.utils import (accounts_update_channel,
+                                  request_account_list_channel)
+from notecoin.huobi.utils.input_checker import (check_currency, check_in_list,
+                                                check_should_not_none)
 
 
 class AccountClient(object):
@@ -146,7 +153,7 @@ class AccountClient(object):
         return self.rest_api_sync_client.request_process(HttpMethod.GET_SIGN, channel, params)
 
     def transfer_between_parent_and_subuser(self, sub_uid: 'int', currency: 'str', amount: 'float',
-                                            transfer_type: 'TransferMasterType'):
+                                            transfer_type: TransferMasterType):
         """
         Transfer Asset between Parent and Sub Account.
 
@@ -171,7 +178,7 @@ class AccountClient(object):
 
         return self.rest_api_sync_client.request_process(HttpMethod.POST_SIGN, channel, params)
 
-    def sub_account_update(self, mode: 'AccountBalanceMode', callback, error_handler=None):
+    def sub_account_update(self, mode: AccountBalanceMode, callback, error_handler=None):
         """
         Subscribe accounts update
 
@@ -224,7 +231,7 @@ class AccountClient(object):
         self.web_socket_req_client.execute_subscribe_v1(subscription, callback, error_handler, is_trade=True)
 
     def transfer_between_futures_and_pro(self, currency: 'str', amount: 'float',
-                                         transfer_type: 'TransferFuturesPro') -> int:
+                                         transfer_type: TransferFuturesPro) -> int:
         """
         Transfer Asset between Futures and Contract.
 
